from setuptools import setup

setup(
    name='oboipark_utils',
    version='0.0.12',
    packages=['oboipark_utils'],
    url='https://gitlab.com/oboipark/utils',
    license='python',
    author='VVD-byte',
    author_email='vovavoronin1999@gmail.com',
    description='утилиты для обоипарк'
)
